<template>
    <div :class="['map-target', !isSub ? 'isSub' : '']">
        <div class="map-tip-container" v-if="isSub">
            <div class="map-container" :element-loading-background="loadingColor" v-loading="loading">
                <div :id="CQId"></div>
                <div :id="main9Id">
                    <div :class="['ljxq', `grade-${ljxqGrade}`]" @click="goToSub('ljxq')">
                        <i class="dot"></i>
                    </div>
                    <div :class="['gxq', `grade-${gxqGrade}`]" @click="goToSub('gxq')">
                        <i class="dot"></i>
                    </div>
                </div>
            </div>
            <div class="fdgz">
                <!-- {{
                    quarter === 2
                        ? ''
                        : `以新争取国家级改革试点的项目数量为评价内容，当季个数为0的为D档，平均值（4.02）以上的按排序等分为A、B档，其余为C档。`
                }} -->
            </div>
            <div class="map-tip">
                <div class="tip-item">
                    <div class="level-title">A档</div>
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">≥4个</div>
                    <div class="tip-text" v-else>
                        <template v-if="year > 2023">
                            &nbsp;&nbsp;≥平均值（3个）<br />等分为两档，第1档
                        </template>
                        <template v-else>
                            &nbsp;&nbsp;≥平均值（{{ meanObj.nationalAddNumAvg }}个）<br />等分为两档，第1档
                        </template>
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">B档</div>
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">
                        ≥3个 且 ＜4个
                    </div>
                    <div class="tip-text" v-else>
                        <template v-if="year > 2023">
                            &nbsp;&nbsp;≥平均值（3个）<br />等分为两档，第2档
                        </template>
                        <template v-else>
                            &nbsp;&nbsp;≥平均值（{{ meanObj.nationalAddNumAvg }}个）<br />等分为两档，第2档
                        </template>
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">C档</div>
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">
                        ≥1个 且 ＜3个
                    </div>
                    <div class="tip-text" v-else>
                        <template v-if="year > 2023">
                            &nbsp;＜平均值（3个）<br />等分为两档，第1档
                        </template>
                        <template v-else>
                            &nbsp;＜平均值（{{ meanObj.nationalAddNumAvg }}个）<br />等分为两档，第1档
                        </template>
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">D档</div>
                    <div class="tip-text" v-if="meanObj.nationalAddNumType === 1">=0个</div>
                    <div class="tip-text" v-else>
                        <template v-if="year > 2023">
                            &nbsp;＜平均值（3个）<br />等分为两档，第2档
                        </template>
                        <template v-else>
                            &nbsp;＜平均值（{{ meanObj.nationalAddNumAvg }}个）<br />等分为两档，第2档
                        </template>
                    </div>
                </div>
            </div>
        </div>

        <div class="list-container">
            <air-table @loadComplete="loadComplete" :data="tableData" :tableColumn="tableColumn" :lsFd="lsFd" :isSub="isSub"></air-table>
        </div>
    </div>
</template>

<script>
import airTable from './airTable.vue'
import mapTargetMixin from '@/mixins/mapTargetMixin.js'
export default {
    mixins: [mapTargetMixin],
    components: {
        airTable,
    },
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
        CQId: {
            type: String,
            default: 'cq-contianer_4',
        },
        main9Id: {
            type: String,
            default: 'main9-contianer_4',
        },
        isClick: {
            type: Boolean,
            default: true,
        },
    },
    data() {
        return {
            tableColumn: [],
            typeNum: 'workableNationalAddNum',
            typeGrade: 'workableNationalAddGrade',
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.setIsSub()
        this.setTableColumn()
        this.initData()
        this.$bus.$on('changeDate', () => {
            this.setIsSub()
            this.setTableColumn()
            this.initData()
        })
        this.$root.$on('resize', () => {
            this.resize(500)
        })
    },
    methods: {
        setIsSub() {
            let { year, quarter } = JSON.parse(sessionStorage.getItem('searchDate'))
            if (year === 2024 && quarter === 2) {
                this.isSub = false
            } else {
                this.isSub = true
            }
            this.setLsFd()
        },
        handleDetail(comp, unitName) {
            let year = new Date().getFullYear()
            let num = new Date(2023, 12, 0).getDate()
            this.$router.push({
                path: '/DetailComponent',
                name: 'DetailComponent',
                query: {
                    unitName,
                    comp,
                    time: [`${year}-01-01`, `${year}-12-${num}`],
                },
            })
        },
        setTableColumn() {
            let { year, quarter } = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            if (this.isSub) {
                if (year === 2023 && quarter === 1) {
                    this.tableColumn = [
                        { label: '区县', prop: 'unitName' },
                        { label: '实际值\n(个)', prop: 'workableNationalAddNum' },
                    ]
                } else if (year === 2023 && (quarter === 2 || quarter === 3)) {
                    this.tableColumn = [
                        { label: '排名', prop: 'workableNationalAddSn' },
                        { label: '区县', prop: 'unitName' },
                        { label: '实际值(个)', prop: 'workableNationalAddNum' },
                    ]
                } else {
                    this.tableColumn = [
                        { label: '排名', prop: 'workableNationalAddSn' },
                        { label: '区县', prop: 'unitName' },
                        { label: '实际值(个)', prop: 'workableNationalAddNum' },
                        { label: '得分', prop: 'workableNationalAddScore' },
                    ]
                }
            } else {
                this.tableColumn = [
                    { label: '排名', prop: 'workableNationalAddSn' },
                    { label: '区县', prop: 'unitName' },
                    { label: '实际值(个)', prop: 'workableNationalAddNum' }
                ]
            }

        },
    },
}
</script>

<style lang="scss" scoped>
@import './target.scss';

.map-tip {
    bottom: 0;
}

.map-target {
    padding: 30PX 35PX;
}

.level-container {
    display: flex;
    flex-direction: column;
    height: 100%;
    flex-wrap: wrap;
    row-gap: 0;
    align-content: flex-end;

    >* {
        width: 30.33%;
        font-family: '微软雅黑', sans-serif !important;
    }

    .level-title {
        display: flex;
        align-items: center;
        justify-content: center;
        text-align: center;
        font-size: 24PX;
        font-weight: bold;
        height: 32PX;
        line-height: 32PX;
        margin-top: 20PX;

        &:last-child {
            margin-bottom: 5px;
        }
    }

    .level-title-A {
        margin-top: 0;
        background-color: #398C8F;
    }

    .level-title-B {
        background-color: #1970c1;
    }

    .level-title-C {
        background-color: #A3A355;
    }

    .level-title-D {
        background-color: #B0825C;
    }

    .level-title-E {
        background-color: #9B4E55;
    }

    .level-header,
    .level-content-item {
        align-items: center;
        margin: 0;
        height: calc(100% / 18);

        span {
            text-align: center;
            font-size: 18px;
            flex: 1;
            text-align: center;

            &:first-child {
                flex: 1.3;
            }

            &:last-child {
                flex: 1;
            }
        }

    }
}
</style>
